==> kdebase-3.1.tar.bz2: kdebase-3.1/kicker/buttons/windowlistbutton.cpp <==
/*****************************************************************

Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qtooltip.h>

#include <kwindowlistmenu.h>
#include <klocale.h>

#include "windowlistbutton.h"
#include "windowlistbutton.moc"

WindowListButton::WindowListButton( QWidget* parent )
  : PanelPopupButton( parent, "WindowListButton" )
  , topMenu( 0 )
{
    topMenu = new KWindowListMenu( this );
    setPopup(topMenu);

    QToolTip::add(this, i18n("Window List"));

    setTitle(i18n("Window List"));
    setIcon("window_list");
}

void WindowListButton::initPopup()
{
    topMenu->init();
}

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kicker/buttons/windowlistbutton.cpp <==
/*****************************************************************

Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qtooltip.h>

#include <kwindowlistmenu.h>
#include <klocale.h>

#include "windowlistbutton.h"
#include "windowlistbutton.moc"

WindowListButton::WindowListButton( QWidget* parent )
  : PanelPopupButton( parent, "WindowListButton" )
  , topMenu( 0 )
{
    topMenu = new KWindowListMenu( this );
    setPopup(topMenu);

    QToolTip::add(this, i18n("Window list"));

    setTitle(i18n("Window List"));
    setIcon("window_list");
}

void WindowListButton::initPopup()
{
    topMenu->init();
}
